@@ -4,9 +4,11 @@ use 5.010;
 use strict;
 use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
-use Log::Any '$log';
+#use Log::Any '$log';
 
-our $VERSION = '1.29'; # VERSION
+use Data::Unixish::Util qw(%common_args);
+
+our $VERSION = '1.30'; # VERSION
 
 our %SPEC;
 
@@ -14,8 +16,7 @@ $SPEC{rev} = {
     v => 1.1,
     summary => 'Reverse items',
     args => {
-        in  => {schema=>'any'},
-        out => {schema=>'any'},
+        %common_args,
     },
     tags => [qw/ordering/],
 };
@@ -48,7 +49,7 @@ Data::Unixish::rev - Reverse items
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -92,8 +93,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<in> => I<any>
 
+Input stream (e.g. array or filehandle).
+
 =item * B<out> => I<any>
 
+Output stream (e.g. array or filehandle).
+
 =back
 
 Return value:
