@@ -5,12 +5,13 @@ use locale;
 use strict;
 use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
-use Log::Any '$log';
+#use Log::Any '$log';
 
+use Data::Unixish::Util qw(%common_args);
 use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 
-our $VERSION = '1.29'; # VERSION
+our $VERSION = '1.30'; # VERSION
 
 our %SPEC;
 
@@ -28,8 +29,7 @@ Undef, hashes, and other non-scalars are ignored.
 
 _
     args => {
-        in  => {schema=>'any'},
-        out => {schema=>'any'},
+        %common_args,
         format => {
             schema=>['str*'],
             cmdline_aliases => { f=>{} },
@@ -100,7 +100,7 @@ Data::Unixish::sprintf - Apply sprintf() on input
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -155,8 +155,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<in> => I<any>
 
+Input stream (e.g. array or filehandle).
+
 =item * B<out> => I<any>
 
+Output stream (e.g. array or filehandle).
+
 =item * B<skip_array> => I<bool> (default: 0)
 
 =item * B<skip_non_number> => I<bool> (default: 0)
