@@ -4,9 +4,11 @@ use 5.010;
 use strict;
 use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
-use Log::Any '$log';
+#use Log::Any '$log';
 
-our $VERSION = '1.29'; # VERSION
+our $VERSION = '1.30'; # VERSION
+
+use Data::Unixish::Util qw(%common_args);
 
 our %SPEC;
 
@@ -14,8 +16,7 @@ $SPEC{tail} = {
     v => 1.1,
     summary => 'Output the last items of data',
     args => {
-        in  => {schema=>'any'},
-        out => {schema=>'any'},
+        %common_args,
         items => {
             summary => 'Number of items to output',
             schema=>['int*' => {default=>10}],
@@ -59,7 +60,7 @@ Data::Unixish::tail - Output the last items of data
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -107,12 +108,16 @@ Arguments ('*' denotes required arguments):
 
 =item * B<in> => I<any>
 
+Input stream (e.g. array or filehandle).
+
 =item * B<items> => I<int> (default: 10)
 
 Number of items to output.
 
 =item * B<out> => I<any>
 
+Output stream (e.g. array or filehandle).
+
 =back
 
 Return value:
