@@ -5,12 +5,13 @@ use locale;
 use strict;
 use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
-use Log::Any '$log';
+#use Log::Any '$log';
 
+use Data::Unixish::Util qw(%common_args);
 use Text::ANSI::Util qw(ta_trunc ta_mbtrunc);
 use Text::WideChar::Util qw(mbtrunc);
 
-our $VERSION = '1.29'; # VERSION
+our $VERSION = '1.30'; # VERSION
 
 our %SPEC;
 
@@ -27,8 +28,7 @@ can turn of `mb` option even when your text contains wide characters.
 
 _
     args => {
-        in  => {schema=>'any'},
-        out => {schema=>'any'},
+        %common_args,
         width => {
             schema => ['int*', min => 0],
             req => 1,
@@ -89,7 +89,7 @@ Data::Unixish::trunc - Truncate string to a certain column width
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -143,12 +143,16 @@ Whether to handle ANSI escape codes.
 
 =item * B<in> => I<any>
 
+Input stream (e.g. array or filehandle).
+
 =item * B<mb> => I<bool> (default: 0)
 
 Whether to handle wide characters.
 
 =item * B<out> => I<any>
 
+Output stream (e.g. array or filehandle).
+
 =item * B<width>* => I<int>
 
 =back
