@@ -6,7 +6,8 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 #use Log::Any '$log';
 
-our $VERSION = '1.29'; # VERSION
+use Data::Unixish::Util qw(%common_args);
+our $VERSION = '1.30'; # VERSION
 
 our %SPEC;
 
@@ -17,8 +18,7 @@ $SPEC{uc} = {
 
 _
     args => {
-        in  => {schema=>'any'},
-        out => {schema=>'any'},
+        %common_args,
     },
     tags => [qw/text/],
 };
@@ -52,7 +52,7 @@ Data::Unixish::uc - Convert text to uppercase
 
 =head1 VERSION
 
-version 1.29
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -94,8 +94,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<in> => I<any>
 
+Input stream (e.g. array or filehandle).
+
 =item * B<out> => I<any>
 
+Output stream (e.g. array or filehandle).
+
 =back
 
 Return value:
